;; Step/theme.jl

;; Copyright (C) 1999 Michele Campeotto <golia@supereva.it>

;; This  theme is based on Window Maker, another window manager for X11
;; (wich is based on Apple NeXTStep), I ported it to Sawmill because I liked
;; his look'n'feel but Window Maker is'nt working well with Gnome (althought
;; it uses less memory than Sawmill ;-) ).

;; Preferences

(defgroup Step-frame "Step frame")

(defcustom Step:flat-buttons nil
  "Use flat buttons on titlebar"
  :group Step-frame
  :type boolean
  :after-set after-setting-frame-option)

(defcustom Step:title-alignement 'center
  "Alignement of the text in the titlebar (needs a restart, why?)"
  :group Step-frame
  :type (set left center right)
  :after-set after-setting-frame-option)

(let* (
	(title-font (get-font "-*-helvetica-bold-r-normal-*-12-*-*-*-*-*-*"))
	(title-colors (list (get-color "black") (get-color "white")))
	(alignement Step:title-alignement)

	(minimize-flat (list
		(make-image "minimize-flat-inactive.png")
		(make-image "minimize-flat-active.png") nil
  		(make-image "minimize-flat-pressed.png")))

	(minimize-bevel (list
		(make-image "minimize-bevel-inactive.png")
		(make-image "minimize-bevel-active.png") nil
  		(make-image "minimize-bevel-pressed.png")))

	(minimize (lambda ()
		(if Step:flat-buttons minimize-flat minimize-bevel)))

	(close-flat (list
		(make-image "close-flat-inactive.png")
		(make-image "close-flat-active.png") nil
  		(make-image "close-flat-pressed.png")))

	(close-bevel (list
		(make-image "close-bevel-inactive.png")
		(make-image "close-bevel-active.png") nil
  		(make-image "close-bevel-pressed.png")))

	(close (lambda ()
		(if Step:flat-buttons close-flat close-bevel)))
	
	(titlebar (list
		(make-image "titlebar-inactive.png")
		(make-image "titlebar-active.png")))

	(top-left (list
		(make-image "top-left-inactive.png")
		(make-image "top-left-active.png")))

	(top-right (list
		(make-image "top-right-inactive.png")
		(make-image "top-right-active.png")))

	(border (make-image "border.png"))

	(bottom (make-image "bottom.png"))
	
	(bottom-left (make-image "bottom-left.png"))
	
	(bottom-right (make-image "bottom-right.png"))

;; Normal window frame
	(frame `(
	;; Minimize button
		((background . ,minimize)
		 (left-edge . -1)
		 (width . 24)
		 (top-edge . -23)
		 (height . 23)
		 (cursor . (get-cursor "cross"))
		 (class . iconify-button))
	;; Titlebar
		((background . ,titlebar)
		 (foreground . ,title-colors)
		 (font . ,title-font)
		 (text . ,window-name)
		 (x-justify . ,alignement)
		 (y-justify . center)
		 (left-edge . 23)
		 (right-edge . 23)
		 (top-edge . -23)
		 (cursor . (get-cursor "cross"))
		 (class . title))
	;; Close button
		((background . ,close)
		 (right-edge . -1)
		 (width . 24)
		 (top-edge . -23)
		 (height . 23)
		 (cursor . (get-cursor "cross"))
		 (class . close-button))
	;; Left border
		((background . ,border)
		 (right-edge . -1)
		 (width . 1)
		 (top-edge . 0)
		 (bottom-edge . -9)
		 (class . right-border))
	;;Right border
		((background . ,border)
		 (left-edge . -1)
		 (width . 1)
		 (top-edge . 0)
		 (bottom-edge . -9)
		 (class . left-border))
	;; Bottom left corner
		((background . ,bottom-left)
		 (left-edge . 0)
		 (width . 30)
		 (bottom-edge . -9)
		 (height . 9)
		 (class . bottom-left-corner))
	;; Bottom border
		((background . ,bottom)
		 (left-edge . 30)
		 (right-edge . 30)
		 (bottom-edge . -9)
		 (height . 9)
		 (class . bottom-border))
	;; Bottom right corner
		((background . ,bottom-right)
		 (right-edge . 0)
		 (width . 30)
		 (bottom-edge . -9)
		 (height . 9)
		 (class . bottom-right-corner))
	)) ;; end frame

;; Normal window shaded frame
	(shaped-frame `(
	;; Minimize button
		((background . ,minimize)
		 (left-edge . -1)
		 (width . 24)
		 (top-edge . -23)
		 (height . 23)
		 (cursor . (get-cursor "cross"))
		 (class . iconify-button))
	;; Titlebar
		((background . ,titlebar)
		 (foreground . ,title-colors)
		 (font . ,title-font)
		 (text . ,window-name)
		 (x-justify . ,alignement)
		 (y-justify . center)
		 (left-edge . 23)
		 (right-edge . 23)
		 (top-edge . -23)
		 (cursor . (get-cursor "cross"))
		 (class . title))
	;; Close button
		((background . ,close)
		 (right-edge . -1)
		 (width . 24)
		 (top-edge . -23)
		 (height . 23)
		 (cursor . (get-cursor "cross"))
		 (class . close-button))
	)) ;; end shaped-frame

;; Dialog window frame
	(transient-frame `(
	;; Top left
		((background . ,top-left)
		 (left-edge . -1)
		 (width . 2)
		 (top-edge . -23)
		 (cursor . (get-cursor "cross"))
		 (class . title))
	;; Titlebar
		((background . ,titlebar)
		 (foreground . ,title-colors)
		 (font . ,title-font)
		 (text . ,window-name)
		 (x-justify . ,alignement)
		 (y-justify . center)
		 (left-edge . 1)
		 (right-edge . 1)
		 (top-edge . -23)
		 (cursor . (get-cursor "cross"))
		 (class . title))
	;; Top right
		((background . ,top-right)
		 (right-edge . -1)
		 (width . 2)
		 (top-edge . -23)
		 (cursor . (get-cursor "cross"))
		 (class . title))
	;; Left border
		((background . ,border)
		 (right-edge . -1)
		 (width . 1)
		 (top-edge . 0)
		 (bottom-edge . -1)
		 (class . right-border))
	;;Right border
		((background . ,border)
		 (left-edge . -1)
		 (width . 1)
		 (top-edge . 0)
		 (bottom-edge . -1)
		 (class . left-border))
	;; Bottom border
		((background . ,border)
		 (left-edge . 0)
		 (right-edge . 0)
		 (bottom-edge . -1)
		 (height . 1)
		 (class . bottom-border))
	)) ;; end transient-frame

;; Dialog window shaded frame
	(shaped-transient-frame `(
	;; Top left
		((background . ,top-left)
		 (left-edge . -1)
		 (width . 2)
		 (top-edge . -23)
		 (cursor . (get-cursor "cross"))
		 (class . title))
	;; Titlebar
		((background . ,titlebar)
		 (foreground . ,title-colors)
		 (font . ,title-font)
		 (text . ,window-name)
		 (x-justify . ,alignement)
		 (y-justify . center)
		 (left-edge . 1)
		 (right-edge . 1)
		 (top-edge . -23)
		 (cursor . (get-cursor "cross"))
		 (class . title))
	;; Top right
		((background . ,top-right)
		 (right-edge . -1)
		 (width . 2)
		 (top-edge . -23)
		 (cursor . (get-cursor "cross"))
		 (class . title))
	))) ;; end shaped-transient-frame

	(add-frame-style 'Step
		(lambda (w type)
			(cond ((eq type 'shaped)
					shaped-frame)
				((eq type 'transient)
					transient-frame)
				((eq type 'shaped-transient)
					shaped-transient-frame)
				((eq type 'unframed)
					nil-frame)
				(t frame)))))